@@ -7,7 +7,7 @@ use test_util as util;
 
 #[test]
 fn compile() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("welcome.exe")
   } else {
@@ -36,12 +36,15 @@ fn compile() {
   assert_eq!(output.stdout, "Welcome to Deno!\n".as_bytes());
 }
 
+// this is ignored, because when building on a release build, the test attempts
+// to download a binary of a yet to be published version.
+// TODO(@kitsonk) https://github.com/denoland/deno/issues/14103
 #[ignore]
 #[test]
 #[cfg(windows)]
 // https://github.com/denoland/deno/issues/9667
 fn compile_windows_ext() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = dir.path().join("welcome_9667");
   let output = util::deno_cmd()
     .current_dir(util::root_path())
@@ -65,7 +68,7 @@ fn compile_windows_ext() {
 
 #[test]
 fn standalone_args() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("args.exe")
   } else {
@@ -101,7 +104,7 @@ fn standalone_args() {
 
 #[test]
 fn standalone_error() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("error.exe")
   } else {
@@ -143,7 +146,7 @@ fn standalone_error() {
 
 #[test]
 fn standalone_error_module_with_imports() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("error.exe")
   } else {
@@ -183,7 +186,7 @@ fn standalone_error_module_with_imports() {
 
 #[test]
 fn standalone_load_datauri() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("load_datauri.exe")
   } else {
@@ -215,7 +218,7 @@ fn standalone_load_datauri() {
 
 #[test]
 fn standalone_compiler_ops() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("standalone_compiler_ops.exe")
   } else {
@@ -247,7 +250,7 @@ fn standalone_compiler_ops() {
 
 #[test]
 fn compile_with_directory_output_flag() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let output_path = if cfg!(windows) {
     dir.path().join(r"args\random\")
   } else {
@@ -285,14 +288,14 @@ fn compile_with_directory_output_flag() {
 
 #[test]
 fn compile_with_file_exists_error() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let output_path = if cfg!(windows) {
     dir.path().join(r"args\")
   } else {
     dir.path().join("args/")
   };
   let file_path = dir.path().join("args");
-  File::create(&file_path).expect("cannot create file");
+  File::create(&file_path).unwrap();
   let output = util::deno_cmd()
     .current_dir(util::testdata_path())
     .arg("compile")
@@ -306,21 +309,27 @@ fn compile_with_file_exists_error() {
     .wait_with_output()
     .unwrap();
   assert!(!output.status.success());
-  let expected_stderr =
-    format!("Could not compile: {:?} is a file.\n", &file_path);
+  let expected_stderr = format!(
+    concat!(
+      "Could not compile to file '{}' because its parent directory ",
+      "is an existing file. You can use the `--output <file-path>` flag to ",
+      "provide an alternative name.\n",
+    ),
+    file_path.display(),
+  );
   let stderr = String::from_utf8(output.stderr).unwrap();
   assert!(stderr.contains(&expected_stderr));
 }
 
 #[test]
 fn compile_with_directory_exists_error() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("args.exe")
   } else {
     dir.path().join("args")
   };
-  std::fs::create_dir(&exe).expect("cannot create directory");
+  std::fs::create_dir(&exe).unwrap();
   let output = util::deno_cmd()
     .current_dir(util::testdata_path())
     .arg("compile")
@@ -334,22 +343,27 @@ fn compile_with_directory_exists_error() {
     .wait_with_output()
     .unwrap();
   assert!(!output.status.success());
-  let expected_stderr =
-    format!("Could not compile: {:?} is a directory.\n", &exe);
+  let expected_stderr = format!(
+    concat!(
+      "Could not compile to file '{}' because a directory exists with ",
+      "the same name. You can use the `--output <file-path>` flag to ",
+      "provide an alternative name."
+    ),
+    exe.display()
+  );
   let stderr = String::from_utf8(output.stderr).unwrap();
   assert!(stderr.contains(&expected_stderr));
 }
 
 #[test]
 fn compile_with_conflict_file_exists_error() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("args.exe")
   } else {
     dir.path().join("args")
   };
-  std::fs::write(&exe, b"SHOULD NOT BE OVERWRITTEN")
-    .expect("cannot create file");
+  std::fs::write(&exe, b"SHOULD NOT BE OVERWRITTEN").unwrap();
   let output = util::deno_cmd()
     .current_dir(util::testdata_path())
     .arg("compile")
@@ -363,19 +377,25 @@ fn compile_with_conflict_file_exists_error() {
     .wait_with_output()
     .unwrap();
   assert!(!output.status.success());
-  let expected_stderr =
-    format!("Could not compile: cannot overwrite {:?}.\n", &exe);
+  let expected_stderr = format!(
+    concat!(
+      "Could not compile to file '{}' because the file already exists ",
+      "and cannot be overwritten. Please delete the existing file or ",
+      "use the `--output <file-path` flag to provide an alternative name."
+    ),
+    exe.display()
+  );
   let stderr = String::from_utf8(output.stderr).unwrap();
   dbg!(&stderr);
   assert!(stderr.contains(&expected_stderr));
   assert!(std::fs::read(&exe)
-    .expect("cannot read file")
+    .unwrap()
     .eq(b"SHOULD NOT BE OVERWRITTEN"));
 }
 
 #[test]
 fn compile_and_overwrite_file() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("args.exe")
   } else {
@@ -413,7 +433,7 @@ fn compile_and_overwrite_file() {
 
 #[test]
 fn standalone_runtime_flags() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("flags.exe")
   } else {
@@ -452,7 +472,7 @@ fn standalone_runtime_flags() {
 
 #[test]
 fn standalone_import_map() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("import_map.exe")
   } else {
@@ -487,7 +507,7 @@ fn standalone_import_map() {
 #[test]
 // https://github.com/denoland/deno/issues/12670
 fn skip_rebundle() {
-  let dir = TempDir::new().expect("tempdir fail");
+  let dir = TempDir::new().unwrap();
   let exe = if cfg!(windows) {
     dir.path().join("hello_world.exe")
   } else {
